import { ref, onUnmounted } from 'vue';
import CryptoJS from 'crypto-js';

// 定义从服务器接收到的数据的结构
interface ServerResponse {
  header: {
    code: number;
    message: string;
    status: number;
    sid?: string;
  };
  payload?: {
    choices?: {
      status: number;
      seq: number;
      text: Array<{
        content: string;
        role: string;
        index: number;
      }>;
    };
    usage?: {
      text: {
        question_tokens: number;
        prompt_tokens: number;
        completion_tokens: number;
        total_tokens: number;
      };
    };
  };
}

// 连接状态枚举
enum ConnectionStatus {
  DISCONNECTED = 'disconnected',
  CONNECTING = 'connecting',
  CONNECTED = 'connected',
  RECONNECTING = 'reconnecting',
  ERROR = 'error'
}

// 配置接口
interface DigitalHumanConfig {
  appId: string;
  apiSecret: string;
  apiKey: string;
  maxReconnectAttempts?: number;
  reconnectInterval?: number;
  heartbeatInterval?: number;
}

// 默认配置
const defaultConfig: DigitalHumanConfig = {
  appId: '379db9f6',
  apiSecret: 'YTJmZTgwY2ZkMWVjMzE5NGY2ZTA4Nzk1',
  apiKey: 'b75ae5315729c32e4d38785aac8e26d0',
  maxReconnectAttempts: 5,
  reconnectInterval: 3000,
  heartbeatInterval: 30000
}

export function useDigitalHuman(onMessage?: (data: ServerResponse) => void, config: Partial<DigitalHumanConfig> = {}) {
  const finalConfig = { ...defaultConfig, ...config };
  
  const ws = ref<WebSocket | null>(null);
  const connectionStatus = ref<ConnectionStatus>(ConnectionStatus.DISCONNECTED);
  const isConnected = ref(false);
  const reconnectAttempts = ref(0);
  const lastError = ref<string | null>(null);
  
  // 定时器
  let reconnectTimer: NodeJS.Timeout | null = null;
  let heartbeatTimer: NodeJS.Timeout | null = null;

  /**
   * 生成鉴权URL
   */
  const generateAuthUrl = (): string => {
    const host = 'spark-api.xf-yun.com';
    const path = '/v3.5/chat';  // 使用星火3.5版本
    const date = new Date().toUTCString();
    
    // 生成签名字符串
    const signatureOrigin = `host: ${host}\ndate: ${date}\nGET ${path} HTTP/1.1`;
    
    // 使用HMAC-SHA256生成签名
    const signature = CryptoJS.HmacSHA256(signatureOrigin, finalConfig.apiSecret);
    const signatureBase64 = CryptoJS.enc.Base64.stringify(signature);
    
    // 生成authorization字符串
    const authorizationOrigin = `api_key="${finalConfig.apiKey}", algorithm="hmac-sha256", headers="host date request-line", signature="${signatureBase64}"`;
    const authorization = btoa(authorizationOrigin);
    
    // 构建WebSocket URL
    const params = new URLSearchParams({
      authorization,
      date,
      host
    });
    
    return `wss://${host}${path}?${params.toString()}`;
  };

  /**
   * 清理定时器
   */
  const clearTimers = () => {
    if (reconnectTimer) {
      clearTimeout(reconnectTimer);
      reconnectTimer = null;
    }
    if (heartbeatTimer) {
      clearInterval(heartbeatTimer);
      heartbeatTimer = null;
    }
  };

  /**
   * 启动心跳检测
   */
  const startHeartbeat = () => {
    clearTimers();
    heartbeatTimer = setInterval(() => {
      if (ws.value && ws.value.readyState === WebSocket.OPEN) {
        send({ type: 'ping' });
      }
    }, finalConfig.heartbeatInterval!);
  };

  /**
   * 处理重连
   */
  const handleReconnect = () => {
    if (reconnectAttempts.value >= finalConfig.maxReconnectAttempts!) {
      console.error('🔌 Maximum reconnection attempts reached');
      connectionStatus.value = ConnectionStatus.ERROR;
      lastError.value = 'Maximum reconnection attempts reached';
      return;
    }

    reconnectAttempts.value++;
    connectionStatus.value = ConnectionStatus.RECONNECTING;
    
    console.log(`🔌 Attempting to reconnect (${reconnectAttempts.value}/${finalConfig.maxReconnectAttempts})...`);
    
    reconnectTimer = setTimeout(() => {
      connect();
    }, finalConfig.reconnectInterval!);
  };

  /**
   * 连接到服务器
   */
  const connect = () => {
    if (connectionStatus.value === ConnectionStatus.CONNECTING || 
        connectionStatus.value === ConnectionStatus.CONNECTED) {
      return;
    }

    try {
      connectionStatus.value = ConnectionStatus.CONNECTING;
      lastError.value = null;
      
      const wsUrl = generateAuthUrl();
      console.log('🔌 Connecting to WebSocket...', wsUrl);
      
      ws.value = new WebSocket(wsUrl);

      ws.value.onopen = () => {
        console.log('🔌 WebSocket connected successfully');
        connectionStatus.value = ConnectionStatus.CONNECTED;
        isConnected.value = true;
        reconnectAttempts.value = 0;
        lastError.value = null;
        
        // 启动心跳检测
        startHeartbeat();
      };

      ws.value.onmessage = (event) => {
        try {
          const data: ServerResponse = JSON.parse(event.data);
          
          // 处理心跳响应
          if (data.header?.message === 'pong') {
            return;
          }
          
          // 调用回调函数处理消息
          if (onMessage) {
            onMessage(data);
          }
        } catch (error) {
          console.error('🔌 Error parsing message:', error);
          lastError.value = 'Message parsing error';
        }
      };

      ws.value.onerror = (error) => {
        console.error('🔌 WebSocket error:', error);
        connectionStatus.value = ConnectionStatus.ERROR;
        isConnected.value = false;
        lastError.value = 'WebSocket connection error';
      };

      ws.value.onclose = (event) => {
        console.log('🔌 WebSocket connection closed:', event.code, event.reason);
        connectionStatus.value = ConnectionStatus.DISCONNECTED;
        isConnected.value = false;
        clearTimers();
        
        // 如果不是主动关闭，尝试重连
        if (event.code !== 1000 && reconnectAttempts.value < finalConfig.maxReconnectAttempts!) {
          handleReconnect();
        }
      };
      
    } catch (error) {
      console.error('🔌 Error creating WebSocket connection:', error);
      connectionStatus.value = ConnectionStatus.ERROR;
      lastError.value = 'Failed to create WebSocket connection';
    }
  };

  /**
   * 发送数据
   */
  const send = (data: object) => {
    if (ws.value && ws.value.readyState === WebSocket.OPEN) {
      try {
        ws.value.send(JSON.stringify(data));
        return true;
      } catch (error) {
        console.error('🔌 Error sending data:', error);
        lastError.value = 'Failed to send data';
        return false;
      }
    } else {
      console.warn('🔌 WebSocket is not connected, cannot send data');
      // 如果连接断开，尝试重连
      if (connectionStatus.value === ConnectionStatus.DISCONNECTED) {
        connect();
      }
      return false;
    }
  };
  
  /**
   * 关闭连接
   */
  const disconnect = () => {
    console.log('🔌 Disconnecting WebSocket...');
    clearTimers();
    reconnectAttempts.value = finalConfig.maxReconnectAttempts!; // 防止自动重连
    
    if (ws.value) {
      ws.value.close(1000, 'Manual disconnect');
      ws.value = null;
    }
    
    connectionStatus.value = ConnectionStatus.DISCONNECTED;
    isConnected.value = false;
  };

  /**
   * 重置连接状态
   */
  const reset = () => {
    disconnect();
    reconnectAttempts.value = 0;
    lastError.value = null;
  };

  // 组件卸载时清理资源
  onUnmounted(() => {
    disconnect();
  });

  return {
    // 状态
    isConnected,
    connectionStatus,
    lastError,
    reconnectAttempts,
    
    // 方法
    connect,
    send,
    disconnect,
    reset
  };
}