import { ref, reactive, computed, watch } from 'vue'
import { useDigitalHuman } from './useDigitalHuman';

// 面试状态枚举
export const InterviewStatus = {
  IDLE: 'IDLE',
  ASKING: 'ASKING',
  LISTENING: 'LISTENING',
  THINKING: 'THINKING',
  GENERATING_LIP_SYNC: 'GENERATING_LIP_SYNC',
  COMPLETED: 'COMPLETED'
} as const

export type InterviewStatusType = typeof InterviewStatus[keyof typeof InterviewStatus]

// 面试问题类型定义
export interface Question {
  id: number
  questionText: string
  questionVideoUrl: string
}

// 面试状态类型定义
export interface InterviewState {
  status: InterviewStatusType
  userAnswer: string
  finalTranscript: string
  isListening: boolean
}

/**
 * 面试核心逻辑控制器
 * 管理整个面试流程的状态和行为
 */

export function useInterview() {
  // 新增：用于存储音频和文本流
  const liveAudio = ref<string[]>([]);
  const liveText = ref('');

  // 处理服务器消息的回调函数
  const handleServerMessage = (data: any) => {
    console.log('📨 Received server message:', data);
    
    if (data.header.code !== 0) {
      console.error("API 错误:", data.header.message);
      return;
    }

    if (data.payload) {
      // 处理讯飞星火API的对话响应
      if (data.payload.choices && data.payload.choices.text) {
        // 处理对话文本流
        data.payload.choices.text.forEach((choice: any) => {
          if (choice.content) {
            liveText.value += choice.content;
            console.log('💬 Received text chunk:', choice.content);
          }
        });
        
        // 当收到文本时，进入口型同步生成状态
        if (interviewState.status === InterviewStatus.THINKING) {
          interviewState.status = InterviewStatus.GENERATING_LIP_SYNC;
        }
      }
      
      // 检查是否为最后一条消息（status: 2表示结束）
      if (data.header.status === 2) {
        console.log('✅ AI response completed');
        // AI回答完成，等待一段时间后进入下一个问题或结束面试
        setTimeout(() => {
          if (isLastQuestion.value) {
            endInterview();
          } else {
            moveToNextQuestion();
          }
        }, 2000); // 等待2秒让用户看完回答
      }
    }
  }
  
  // 模拟面试问题数据
  const questions = ref<Question[]>([
    {
      id: 1,
      questionText: "请简单介绍一下你自己。",
      questionVideoUrl: "https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4"
    },
    {
      id: 2,
      questionText: "你为什么选择这个职位？",
      questionVideoUrl: "https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ElephantsDream.mp4"
    },
    {
      id: 3,
      questionText: "请描述一下你的职业规划。",
      questionVideoUrl: "https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ForBiggerBlazes.mp4"
    },
    {
      id: 4,
      questionText: "你有什么问题想问我们吗？",
      questionVideoUrl: "https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ForBiggerEscapes.mp4"
    }
  ])

  // 当前问题索引
  const currentQuestionIndex = ref(0)

  // 面试状态
  const interviewState = reactive<InterviewState>({
    status: InterviewStatus.IDLE,
    userAnswer: '',
    finalTranscript: '',
    isListening: false
  })

  // 面试时长控制（15分钟 = 900秒）
  const totalInterviewTime = 900
  const remainingTime = ref(totalInterviewTime)
  const isTimerRunning = ref(false)
  let timerInterval: number | null = null

  // 集成数字人WebSocket连接
  const digitalHumanConfig = {
    appId: '379db9f6',
    apiSecret: 'YTJmZTgwY2ZkMWVjMzE5NGY2ZTA4Nzk1',
    apiKey: 'b75ae5315729c32e4d38785aac8e26d0'
  }
  const { isConnected, connect, send, disconnect } = useDigitalHuman(handleServerMessage, digitalHumanConfig)

  // 计算属性
  const currentQuestion = computed(() => {
    return questions.value[currentQuestionIndex.value]
  })

  const totalQuestions = computed(() => questions.value.length)

  const isLastQuestion = computed(() => {
    return currentQuestionIndex.value >= questions.value.length - 1
  })

  const formattedTime = computed(() => {
    const minutes = Math.floor(remainingTime.value / 60)
    const seconds = remainingTime.value % 60
    return `${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}`
  })

  // 模拟Lottie动画数据
  const mockLottieData = {
    v: "5.7.4",
    fr: 30,
    ip: 0,
    op: 90,
    w: 400,
    h: 400,
    nm: "Talking Animation",
    assets: [],
    layers: [
      {
        ddd: 0,
        ind: 1,
        ty: 4,
        nm: "Mouth",
        sr: 1,
        ks: {
          o: { a: 0, k: 100 },
          r: { a: 0, k: 0 },
          p: { a: 0, k: [200, 200, 0] },
          a: { a: 0, k: [0, 0, 0] },
          s: { a: 0, k: [100, 100, 100] }
        },
        ao: 0,
        shapes: [
          {
            ty: "el",
            p: { a: 0, k: [0, 0] },
            s: { a: 1, k: [
              { t: 0, s: [20, 8] },
              { t: 15, s: [25, 15] },
              { t: 30, s: [20, 8] },
              { t: 45, s: [30, 12] },
              { t: 60, s: [20, 8] },
              { t: 75, s: [25, 15] },
              { t: 90, s: [20, 8] }
            ]},
            d: 1
          }
        ],
        ip: 0,
        op: 90,
        st: 0,
        bm: 0
      }
    ]
  }

  /**
   * 提问函数
   */
  const askQuestion = () => {
    interviewState.status = InterviewStatus.ASKING;
    const question = currentQuestion.value;
    if (!question) return;
    
    // 清空上一轮的音视频数据
    liveAudio.value = [];
    liveText.value = '';

    // 发送问题给讯飞星火API（对话格式）
    const questionData = {
      header: {
        app_id: digitalHumanConfig.appId,
        uid: `user_${Date.now()}`
      },
      parameter: {
        chat: {
          domain: "generalv3.5",
          temperature: 0.5,
          max_tokens: 2048
        }
      },
      payload: {
        message: {
          text: [
            {
              role: "system",
              content: "你是一位专业的面试官，请根据求职者的回答进行深入追问和评估。"
            },
            {
              role: "user",
              content: question.questionText
            }
          ]
        }
      }
    }
    send(questionData);
  };

  /**
   * 开始面试流程
   */
  const startInterview = () => {
    console.log('🎯 Starting interview process...')
    currentQuestionIndex.value = 0
    startTimer()
    
    // 建立 WebSocket 连接
    connect();
    
    // 监听连接状态，连接成功后开始提问
    watch(isConnected, (newVal) => {
      if (newVal) {
        askQuestion(); // 连接成功后开始提问
      }
    });
  }

  /**
   * 处理用户回答
   * @param answer 用户的回答文本
   */
  const processUserAnswer = (answer: string) => {
    console.log('🗣️ Processing user answer:', answer)
    interviewState.userAnswer = answer
    interviewState.finalTranscript = answer
    interviewState.isListening = false
    
    // 进入思考状态
    interviewState.status = InterviewStatus.THINKING
    console.log('🤔 AI is thinking...')
    
    // 这里不需要手动发送，因为音频数据会通过VoiceInputHandler实时发送
    // processUserAnswer主要用于处理文本输入的情况
    console.log('User answer processed, waiting for AI response...')

    // 后续的流程会由 handleServerMessage 中对 TTS 和 NLP 的处理来驱动
    // 当收到完整回复后，会自动进入下一个问题或结束面试
  }

  /**
   * 移动到下一个问题
   */
  const moveToNextQuestion = () => {
    console.log('➡️ Moving to next question...')
    currentQuestionIndex.value++
    interviewState.userAnswer = ''
    interviewState.finalTranscript = ''
    
    // 直接调用askQuestion开始新问题
    askQuestion();
  }

  /**
   * 结束面试
   */
  const endInterview = () => {
    console.log('🎉 Interview completed!')
    interviewState.status = InterviewStatus.COMPLETED
    stopTimer()
    // 断开WebSocket连接
    disconnect()
  }

  /**
   * 开始计时器
   */
  const startTimer = () => {
    if (!isTimerRunning.value) {
      isTimerRunning.value = true
      timerInterval = setInterval(() => {
        if (remainingTime.value > 0) {
          remainingTime.value--
        } else {
          // 时间到，强制结束面试
          endInterview()
        }
      }, 1000)
    }
  }

  /**
   * 停止计时器
   */
  const stopTimer = () => {
    if (timerInterval) {
      clearInterval(timerInterval)
      timerInterval = null
    }
    isTimerRunning.value = false
  }

  /**
   * 重置面试状态
   */
  const resetInterview = () => {
    console.log('🔄 Resetting interview state...')
    currentQuestionIndex.value = 0
    interviewState.status = InterviewStatus.IDLE
    interviewState.userAnswer = ''
    interviewState.finalTranscript = ''
    interviewState.isListening = false
    remainingTime.value = totalInterviewTime
    stopTimer()
    // 断开WebSocket连接
    disconnect()
    // 清空音频和文本数据
    liveAudio.value = []
    liveText.value = ''
  }

  return {
    // 状态
    questions: questions.value,
    currentQuestionIndex,
    interviewState,
    currentQuestion,
    totalQuestions,
    isLastQuestion,
    remainingTime,
    formattedTime,
    isTimerRunning,
    mockLottieData,
    liveAudio,
    liveText,
    isConnected,
    
    // 方法
    startInterview,
    processUserAnswer,
    moveToNextQuestion,
    endInterview,
    resetInterview,
    startTimer,
    stopTimer,
    askQuestion,
    send
  }
  
}